:project:   Balladeer JS typeahead example
:pause:     0
:dwell:     0.4

.. entity:: DRAMA
    :types: balladeer.Drama

End
===

None
----

.. condition:: DRAMA.count 0

**No** green bottles hanging on the wall!

